@@ -413,14 +413,21 @@ class HiddenMarkovModel(Model):
         """
         return -self.transition_model.lagtime / np.log(np.diag(self.transition_model.transition_matrix))
 
-    def compute_viterbi_paths(self, observations) -> List[np.ndarray]:
+    def compute_viterbi_paths(self, observations, map_observations_to_submodel: bool = False) -> List[np.ndarray]:
         r"""
         Computes the Viterbi paths using the current HMM model.
 
+        Note:
+        In  case of sub-modeling a discrete state HMM, the observation sequence must be mapped to the active states of
+        that sub-model. This can either be done by hand beforehand or by activating the map_observations_to_submodel
+        flag.
+
         Parameters
         ----------
         observations : list of array_like or array_like
             observations
+        map_observations_to_submodel : bool, optional, default = False
+            If True and in case of a discrete output model, activates automatic mapping to the active sub-model states
 
         Returns
         -------
@@ -428,6 +435,8 @@ class HiddenMarkovModel(Model):
             the computed viterbi paths
         """
         observations = ensure_dtraj_list(observations)
+        if map_observations_to_submodel and isinstance(self.output_model, DiscreteOutputModel):
+            observations = self.output_model.map_observations_to_submodel(observations)
         A = self.transition_model.transition_matrix
         pi = self.initial_distribution
         state_probabilities = [
@@ -829,6 +838,14 @@ class HiddenMarkovModel(Model):
                                   observation_symbols_full=self.observation_symbols_full)
         return model
 
+    def _check_connectivity_threshold(self, connectivity_threshold: Union[float, str]) -> float:
+        if str(connectivity_threshold) == '1/n':
+            connectivity_threshold = 1.0 / float(self.transition_model.n_states)
+        elif isinstance(connectivity_threshold, str):
+            raise RuntimeError('Connectivity threshold must be a float or 1/n.')
+
+        return connectivity_threshold
+
     def _select_states(self, connectivity_threshold, states) -> np.ndarray:
         r"""
         Retrieves a selection of states based on the arguments provided.
@@ -844,8 +861,9 @@ class HiddenMarkovModel(Model):
         -------
         A ndarray containing a subselection of states.
         """
-        if str(connectivity_threshold) == '1/n':
-            connectivity_threshold = 1.0 / float(self.transition_model.n_states)
+
+        connectivity_threshold = self._check_connectivity_threshold(connectivity_threshold)
+
         if isinstance(states, str):
             strong = 'strong' in states
             largest = 'largest' in states
@@ -989,6 +1007,7 @@ class HiddenMarkovModel(Model):
         hmm : HiddenMarkovModel
             The restricted HMM.
         """
+        connectivity_threshold = self._check_connectivity_threshold(connectivity_threshold)
         lcc = self.transition_model.count_model.connected_sets(connectivity_threshold=connectivity_threshold)[0]
         return self.submodel(lcc)
 
